==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/SelectionDisplay/ts/SelectionDisplay_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>SelectionDisplay</name>
    <message>
        <source>No selected entities.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Nessun entità selezionate.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.js" line="+58"/>
        <source>No entities selected.</source>
        <translation>Nessun entità selezionate.</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>%1 %2 on Layer &apos;%3&apos;</source>
        <translation>%1 %2 su layer &apos;%3&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 %2 on %3 Layers</source>
        <translation>%1 %2 su %3 layers</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 Entities on Layer &apos;%2&apos;</source>
        <translation>%1 entità su layer &apos;%2&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 Entities on %2 Layers</source>
        <translation>%1 entità su %2 layers</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crea un blocco nuovo dalle entità esistenti
Crea un blocco nuovo dalle entità esistenti

Deseleziona Tutti gli Oggetti</translatorcomment>
        <translation type="vanished">Entità</translation>
    </message>
    <message>
        <source> on </source>
        <translatorcomment>--google--
Vai alla Riga di Comando
Vai alla &amp;Riga di Comando
Il punto di taglio non è sull&apos;oggetto.</translatorcomment>
        <translation type="obsolete">su</translation>
    </message>
    <message>
        <source>on</source>
        <translation type="vanished">su</translation>
    </message>
    <message>
        <source>Layer &apos;%1&apos;</source>
        <translatorcomment>--google--
Layer &apos;%1&apos; convertito con successo 
Conversione non riuscita per il layer &apos;%1&apos;</translatorcomment>
        <translation type="vanished">Strato &apos;%1&apos;</translation>
    </message>
    <message>
        <source>%1 Layers</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">%1 Layers</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Selected entities:
%1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entità selezionate:
%1</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.ui" line="+26"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/SelectionDisplay/ts/SelectionDisplay_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>SelectionDisplay</name>
    <message>
        <source>No selected entities.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Nessun entità selezionate.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.js" line="+58"/>
        <source>No entities selected.</source>
        <translation>Nessun entità selezionate.</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>%1 %2 on Layer &apos;%3&apos;</source>
        <translation>%1 %2 su layer &apos;%3&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 %2 on %3 Layers</source>
        <translation>%1 %2 su %3 layers</translation>
    </message>
    <message numerus="yes">
        <location line="+4"/>
        <source>%n Entities on Layer &apos;%1&apos;</source>
        <translation>
            <numerusform>%n entità su layer &apos;%1&apos;</numerusform>
            <numerusform>%n entità su layer &apos;%1&apos;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>%n Entities</source>
        <translation>
            <numerusform>%n ente</numerusform>
            <numerusform>%n entità</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+0"/>
        <source>%n Layers</source>
        <translation>
            <numerusform>%n layer</numerusform>
            <numerusform>%n layers</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 Entities on Layer &apos;%2&apos;</source>
        <translation type="vanished">%1 entità su layer &apos;%2&apos;</translation>
    </message>
    <message>
        <source>%1 Entities on %2 Layers</source>
        <translation type="vanished">%1 entità su %2 layers</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crea un blocco nuovo dalle entità esistenti
Crea un blocco nuovo dalle entità esistenti

Deseleziona Tutti gli Oggetti</translatorcomment>
        <translation type="vanished">Entità</translation>
    </message>
    <message>
        <source> on </source>
        <translatorcomment>--google--
Vai alla Riga di Comando
Vai alla &amp;Riga di Comando
Il punto di taglio non è sull&apos;oggetto.</translatorcomment>
        <translation type="obsolete">su</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>on</source>
        <translation>su</translation>
    </message>
    <message>
        <source>Layer &apos;%1&apos;</source>
        <translatorcomment>--google--
Layer &apos;%1&apos; convertito con successo 
Conversione non riuscita per il layer &apos;%1&apos;</translatorcomment>
        <translation type="vanished">Strato &apos;%1&apos;</translation>
    </message>
    <message>
        <source>%1 Layers</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">%1 Layers</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Selected entities:
%1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entità selezionate:
%1</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.ui" line="+26"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
</context>
</TS>
